@@ -1,5 +1,5 @@
 /*
- * BluezQt - Asynchronous Bluez wrapper library
+ * BluezQt - Asynchronous BlueZ wrapper library
  *
  * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
  *
@@ -28,14 +28,24 @@
 namespace BluezQt
 {
 
+class Manager;
 class Adapter;
 class Device;
+class Input;
+class MediaPlayer;
+class ObexManager;
+class ObexSession;
 class ObexTransfer;
 
+typedef QSharedPointer<BluezQt::Manager> ManagerPtr;
 typedef QSharedPointer<BluezQt::Adapter> AdapterPtr;
 typedef QSharedPointer<BluezQt::Device> DevicePtr;
+typedef QSharedPointer<BluezQt::Input> InputPtr;
+typedef QSharedPointer<BluezQt::MediaPlayer> MediaPlayerPtr;
+typedef QSharedPointer<BluezQt::ObexManager> ObexManagerPtr;
+typedef QSharedPointer<BluezQt::ObexSession> ObexSessionPtr;
 typedef QSharedPointer<BluezQt::ObexTransfer> ObexTransferPtr;
 
-}
+} // namespace BluezQt
 
 #endif // BLUEZQT_TYPES_H
